/*
 * JBoss, the OpenSource J2EE webOS
 *
 * Distributable under LGPL license.
 * See terms of license at gnu.org.
 */
package transaction.entity;

import transaction.interfaces.CustomerData;
import transaction.interfaces.CustomerPK;

/**
 * The Entity bean represents a bank customer
 *
 * @author Andreas Schaefer
 * @version $Revision: 1.1 $
 *
 * @ejb:bean name="bank/Customer"
 *           display-name="Bank Customer Entity"
 *           type="CMP"
 *           view-type="remote"
 *           jndi-name="ejb/bank/Customer"
 *           schema="Customer"
 *
 * @ejb:interface extends="javax.ejb.EJBObject"
 *
 * @ejb:home extends="javax.ejb.EJBHome"
 *
 * @ejb:pk extends="java.lang.Object"
 *
 * @ejb:transaction type="Required"
 *
 * @ejb:data-object extends="java.lang.Object"
 *                  setdata="true"
 *
 * @ejb:finder signature="java.util.Collection findAll()"
 *
 * @ejb:finder signature="java.util.Collection findByBank( java.lang.String pBankId )"
 *             query="SELECT OBJECT(o) FROM Customer o WHERE o.bankId = ?1"
 *
 * @jboss:finder-query name="findByBank"
 *                     query="bankId = {0}"
 *                     order="bankId"
 *
 * @jboss:table-name table-name="New_Customer"
 *
 * @jboss:create-table create="true"
 *
 * @jboss:remove-table remove="true"
 */
public abstract class CustomerBean
   extends EntitySupport
{
   // Constants -----------------------------------------------------
    
   // Attributes ----------------------------------------------------
   
   // Static --------------------------------------------------------
   
   public static int sId = 0;
   
   // Constructors --------------------------------------------------
   
   // Public --------------------------------------------------------
   
   /**
    * @ejb:persistent-field
    * @ejb:pk-field
    *
    * @jboss:column-name name="Id"
    **/
   abstract public String getId();
   
   abstract public void setId( String pId );
   
   /**
    * @ejb:persistent-field
    *
    * @jboss:column-name name="Bank_Id"
    **/
   abstract public String getBankId();
   
   abstract public void setBankId( String pBankId );
   
   /**
    * @ejb:persistent-field
    *
    * @jboss:column-name name="Name"
    **/
   abstract public String getName();
   
   abstract public void setName( String pName );
   
   /**
    * @ejb:interface-method view-type="remote"
    **/
   public abstract CustomerData getData();
   
   /**
    * @ejb:interface-method view-type="remote"
    **/
   public abstract void setData( CustomerData pData );
   
   // EntityHome implementation -------------------------------------
   
   /**
    * @ejb:create-method view-type="remote"
    **/
   public CustomerPK ejbCreate( String pBankId, String pName ) {
      setId( "" + ( sId++ ) );
      System.out.println( "Created Customer with ID: " + getId() );
      setBankId( pBankId );
      setName( pName );
      
      return null;
   }
   
   public void ejbPostCreate( String pBankId, String pName ) 
   { 
   }
}
